use super::{
    get_player_item_or_fail, search_item_for_user, user_error, UResult, UserVerb, UserVerbRef,
    VerbContext,
};
use crate::db::ItemSearchParams;
use async_trait::async_trait;

pub struct Verb;
#[async_trait]
impl UserVerb for Verb {
    async fn handle(
        self: &Self,
        ctx: &mut VerbContext,
        verb: &str,
        remaining: &str,
    ) -> UResult<()> {
        let player_item = (*(get_player_item_or_fail(ctx).await?)).clone();
        if verb == "follow" {
            let follow_who = search_item_for_user(
                ctx,
                &ItemSearchParams {
                    include_loc_contents: true,
                    ..ItemSearchParams::base(&player_item, remaining.trim())
                },
            )
            .await?;
            if follow_who.item_type != "player" && follow_who.item_type != "npc" {
                user_error("Only characters (player / NPC) can be followed.".to_owned())?;
            }
            if let Some(follow) = player_item.following.as_ref() {
                if follow.follow_whom == player_item.refstr() {
                    user_error(format!(
                        "You're already following {}!",
                        follow_who.pronouns.possessive
                    ))?;
                }
                // sess_dets.queue.filter()
            }
        } else {
        }
        user_error("Sorry, we're still building the follow command!".to_owned())?;
        Ok(())
    }
}
static VERB_INT: Verb = Verb;
pub static VERB: UserVerbRef = &VERB_INT as UserVerbRef;
